Package 'sampleTestPackage'

Title: What the Package Does Using Title Case
Description: A simple package showing different unit testing approaches.
Authors: Dirk Eddelbuettel
Maintainer: Dirk Eddelbuettel <[email protected]>
License: GPL (>= 2)
Version: 1.0.2
Built: 2026-05-07 08:48:27 UTC
Source: https://github.com/eddelbuettel/sampletestpackage

Help Index


What the Package Does Using Title Case

Description

A simple package showing different unit testing approaches.

Details

The DESCRIPTION file:

Package: sampleTestPackage
Type: Package
Title: What the Package Does Using Title Case
Version: 1.0.2
Date: 2021-10-30
Author: Dirk Eddelbuettel
Maintainer: Dirk Eddelbuettel <[email protected]>
Description: A simple package showing different unit testing approaches.
Suggests: RUnit, testthat, tinytest
License: GPL (>= 2)
RoxygenNote: 6.1.1
Repository: https://eddelbuettel.r-universe.dev
Date/Publication: 2026-02-06 13:44:08 UTC
RemoteUrl: https://github.com/eddelbuettel/sampletestpackage
RemoteRef: HEAD
RemoteSha: 54b6bb1fe69066ae7981df089b4daf226c72236f

Index of help topics:

c2f                     Convert temperature in Fahrenheit into Celsius
hello                   A simple function doing little
hello2                  A simple function doing little
sampleTestPackage-package
                        What the Package Does Using Title Case

This section should provide a more detailed overview of how to use the package, including the most important functions.

Author(s)

Dirk Eddelbuettel

Maintainer: Dirk Eddelbuettel <[email protected]>


Convert temperature in Fahrenheit into Celsius

Description

Convert temperature in Fahrenheit into Celsius

Usage

c2f(c)

Arguments

c

Temperature in C

Value

The temperature in F

Examples

c2f(100)

A simple function doing little

Description

This function shows a standard text on the console. In a time-honoured tradition, it defaults to displaying hello, world.

Examples

hello()
  hello("and goodbye")

A simple function doing little

Description

A simple function doing little

Usage

hello2(txt = "world")

Arguments

txt

A text argument

Value

Nothing, side effect of cat()

Examples

hello("world")