| Title: | What the Package Does Using Title Case |
|---|---|
| Description: | A simple package showing different unit testing approaches. |
| Authors: | Dirk Eddelbuettel |
| Maintainer: | Dirk Eddelbuettel <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0.2 |
| Built: | 2026-05-07 08:48:27 UTC |
| Source: | https://github.com/eddelbuettel/sampletestpackage |
A simple package showing different unit testing approaches.
The DESCRIPTION file:
| Package: | sampleTestPackage |
| Type: | Package |
| Title: | What the Package Does Using Title Case |
| Version: | 1.0.2 |
| Date: | 2021-10-30 |
| Author: | Dirk Eddelbuettel |
| Maintainer: | Dirk Eddelbuettel <[email protected]> |
| Description: | A simple package showing different unit testing approaches. |
| Suggests: | RUnit, testthat, tinytest |
| License: | GPL (>= 2) |
| RoxygenNote: | 6.1.1 |
| Repository: | https://eddelbuettel.r-universe.dev |
| Date/Publication: | 2026-02-06 13:44:08 UTC |
| RemoteUrl: | https://github.com/eddelbuettel/sampletestpackage |
| RemoteRef: | HEAD |
| RemoteSha: | 54b6bb1fe69066ae7981df089b4daf226c72236f |
Index of help topics:
c2f Convert temperature in Fahrenheit into Celsius
hello A simple function doing little
hello2 A simple function doing little
sampleTestPackage-package
What the Package Does Using Title Case
This section should provide a more detailed overview of how to use the package, including the most important functions.
Dirk Eddelbuettel
Maintainer: Dirk Eddelbuettel <[email protected]>
Convert temperature in Fahrenheit into Celsius
c2f(c)c2f(c)
c |
Temperature in C |
The temperature in F
c2f(100)c2f(100)
This function shows a standard text on the console. In a time-honoured tradition, it defaults to displaying hello, world.
hello() hello("and goodbye")hello() hello("and goodbye")
A simple function doing little
hello2(txt = "world")hello2(txt = "world")
txt |
A text argument |
Nothing, side effect of cat()
hello("world")hello("world")